hdMTD: Inference in MTD models

View source: R/hdMTD.R

hdMTDR Documentation

Inference in MTD models

Description

This function estimates the relevant lag set in a Mixture Transition Distribution (MTD) model using one of the available methods. By default, it applies the Forward Stepwise ("FS") method, which is particularly useful in high-dimensional settings. The available methods are:

  • "FS" (Forward Stepwise): selects the lags by a criteria that depends on their oscillations.

  • "CUT": a method that selects the relevant lag set based on a predefined threshold.

  • "FSC" (Forward Stepwise and Cut): applies the "FS" method followed by the "CUT" method.

  • "BIC": selects the lag set using the Bayesian Information Criterion.

Usage

hdMTD(X, d, method = "FS", ...)

Arguments

X

A vector or single-column data frame containing a chain sample.

d

A positive integer representing an upper bound for the chain order.

method

A character string indicating the method for estimating the relevant lag set. The available methods are: "FS" (default), "FSC", "CUT", and "BIC". See the Details section and the documentation of the corresponding method functions for more information.

...

Additional arguments for the selected method. If not specified, default values will be used (see Details ).

Details

The function dynamically calls the corresponding method function (e.g., hdMTD_FSC() for method = "FSC"). Additional parameters specific to each method can be provided via ..., and default values are used for unspecified parameters.

#' This function serves as a wrapper for the method-specific functions:

  • hdMTD_FS(), for method = "FS"

  • hdMTD_FSC(), for method = "FSC"

  • hdMTD_CUT(), for method = "CUT"

  • hdMTD_BIC(), for method = "BIC"

Any additional parameters (...) must match those accepted by the corresponding method function. If a parameter value is not explicitly provided, a default value is used. The main default parameters are:

  • S = seq_len(d): Used in "BIC" or "CUT" methods.

  • l = d. Required in "FS" or "FSC" methods.

  • alpha = 0.05, mu = 1. Used in "CUT" or "FSC" methods.

  • xi = 0.5. Used in "CUT", "FSC" or "BIC" methods.

  • minl = 1, maxl = length(S), byl = FALSE. Used in "BIC" method. All default values are specified in the documentation of the method-specific functions.

Value

A vector containing the estimated relevant lag set.

Examples

X <- testChains[,1]
hdMTD(X = X, d = 5, method = "FS", l = 2)
hdMTD(X = X, d = 5, method = "BIC", xi = 1, minl = 3, maxl = 3)


hdMTD documentation built on June 8, 2025, 10:30 a.m.